Exception: Lightstreamer::ClientVersionNotSupportedError
- Defined in:
- lib/lightstreamer/errors.rb
Overview
This error is raised when the client version requested is not supported by the server.
This error is raised when the client version requested is not supported by the server.