Exception: Lightstreamer::Errors::MetadataAdapterError

Inherits:
LightstreamerError show all
Defined in:
lib/lightstreamer/errors.rb

Overview

This error is raised when a error defined by a metadata adapter is raised.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from LightstreamerError

build

Constructor Details

#initialize(message, code) ⇒ MetadataAdapterError

Initializes this metadata adapter error with the specified error message and error code.

Parameters:

  • message (String)

    The error message.

  • code (Fixnum)

    The error code.



118
119
120
121
122
123
# File 'lib/lightstreamer/errors.rb', line 118

def initialize(message, code)
  @adapter_error_message = message
  @adapter_error_code = code

  super message
end

Instance Attribute Details

#adapter_error_codeFixnum (readonly)

The error code from the metadata adapter.

Returns:

  • (Fixnum)


112
113
114
# File 'lib/lightstreamer/errors.rb', line 112

def adapter_error_code
  @adapter_error_code
end

#adapter_error_messageString (readonly)

The error message from the metadata adapter.

Returns:

  • (String)


107
108
109
# File 'lib/lightstreamer/errors.rb', line 107

def adapter_error_message
  @adapter_error_message
end