Exception: Lightstreamer::IncompatibleSessionError

Inherits:
Error
  • Object
show all
Defined in:
lib/lightstreamer/errors.rb

Overview

This error is raise when trying to bind to a session that was initialized with a different and incompatible communication protocol.

Method Summary

Methods inherited from Error

build