Exception: Lightstreamer::MetadataAdapterError

Inherits:
Error
  • Object
show all
Defined in:
lib/lightstreamer/errors.rb

Overview

This error is raised when a error defined by a metadata adapter is raised.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Error

build

Constructor Details

#initialize(message, code) ⇒ MetadataAdapterError

Initializes this metadata adapter error with the specified error message and error code.



109
110
111
112
113
114
# File 'lib/lightstreamer/errors.rb', line 109

def initialize(message, code)
  @adapter_error_message = message
  @adapter_error_code = code.to_i

  super message
end

Instance Attribute Details

#adapter_error_codeFixnum (readonly)

Returns The error code from the metadata adapter.

Returns:

  • (Fixnum)

    The error code from the metadata adapter.



106
107
108
# File 'lib/lightstreamer/errors.rb', line 106

def adapter_error_code
  @adapter_error_code
end

#adapter_error_messageString (readonly)

Returns The error message from the metadata adapter.

Returns:

  • (String)

    The error message from the metadata adapter.



103
104
105
# File 'lib/lightstreamer/errors.rb', line 103

def adapter_error_message
  @adapter_error_message
end