Exception: Lightstreamer::SessionEndError

Inherits:
Error
  • Object
show all
Defined in:
lib/lightstreamer/errors.rb

Overview

This error is raised when the specified session ID is for a session that has been terminated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Error

build

Constructor Details

#initialize(cause_code = nil) ⇒ SessionEndError

Initializes this session end error with the specified cause code.



130
131
132
133
# File 'lib/lightstreamer/errors.rb', line 130

def initialize(cause_code = nil)
  @cause_code = cause_code.to_i
  super()
end

Instance Attribute Details

#cause_codeFixnum (readonly)



125
126
127
# File 'lib/lightstreamer/errors.rb', line 125

def cause_code
  @cause_code
end