Exception: Lightstreamer::StreamingNotAvailableError
- Defined in:
- lib/lightstreamer/errors.rb
Overview
This error is raised when streaming is not available because of the current license terms.
This error is raised when streaming is not available because of the current license terms.