Exception: Lightstreamer::SyncError

Inherits:
Error
  • Object
show all
Defined in:
lib/lightstreamer/errors.rb

Overview

This error is raised when a sync error occurs, which most often means that the session ID provided is invalid and a new session needs to be created.

Method Summary

Methods inherited from Error

build