Exception: Lightstreamer::TableModificationNotAllowedError

Inherits:
Error
  • Object
show all
Defined in:
lib/lightstreamer/errors.rb

Overview

This error is raised when the specified table can’t be modified because it is configured for unfiltered dispatching.

Method Summary

Methods inherited from Error

build