Exception: Lightstreamer::UnfilteredDispatchingNotSupportedForItemError

Inherits:
Error
  • Object
show all
Defined in:
lib/lightstreamer/errors.rb

Overview

This error is raised when unfiltered dispatching is requested on an item that does not support it.

Method Summary

Methods inherited from Error

build