Exception: Lightstreamer::UnsupportedModeForItemError

Inherits:
Error
  • Object
show all
Defined in:
lib/lightstreamer/errors.rb

Overview

This error is raised when the specified subscription mode is not supported by one of the items.

Method Summary

Methods inherited from Error

build