Exception: Lightstreamer::Errors::MetadataAdapterError
- Inherits:
-
LightstreamerError
- Object
- StandardError
- LightstreamerError
- Lightstreamer::Errors::MetadataAdapterError
- Defined in:
- lib/lightstreamer/errors.rb
Overview
This error is raised when a error defined by a metadata adapter is raised.
Instance Attribute Summary collapse
-
#adapter_error_code ⇒ Fixnum
readonly
The error code from the metadata adapter.
-
#adapter_error_message ⇒ String
readonly
The error message from the metadata adapter.
Instance Method Summary collapse
-
#initialize(message, code) ⇒ MetadataAdapterError
constructor
Initializes this metadata adapter error with the specified error message and error code.
Methods inherited from LightstreamerError
Constructor Details
#initialize(message, code) ⇒ MetadataAdapterError
Initializes this metadata adapter error with the specified error message and error code.
118 119 120 121 122 123 |
# File 'lib/lightstreamer/errors.rb', line 118 def initialize(, code) = @adapter_error_code = code super end |
Instance Attribute Details
#adapter_error_code ⇒ Fixnum (readonly)
The error code from the metadata adapter.
112 113 114 |
# File 'lib/lightstreamer/errors.rb', line 112 def adapter_error_code @adapter_error_code end |
#adapter_error_message ⇒ String (readonly)
The error message from the metadata adapter.
107 108 109 |
# File 'lib/lightstreamer/errors.rb', line 107 def end |