Exception: Lightstreamer::IncompatibleSessionError
- Defined in:
- lib/lightstreamer/errors.rb
Overview
This error is raise when trying to bind to a session that was initialized with a different and incompatible communication protocol.
This error is raise when trying to bind to a session that was initialized with a different and incompatible communication protocol.