Exception: Lightstreamer::MetadataAdapterError
- Defined in:
- lib/lightstreamer/errors.rb
Overview
This error is raised when a error defined by a metadata adapter is raised.
Instance Attribute Summary collapse
-
#adapter_error_code ⇒ Fixnum
readonly
The error code from the metadata adapter.
-
#adapter_error_message ⇒ String
readonly
The error message from the metadata adapter.
Instance Method Summary collapse
-
#initialize(message, code) ⇒ MetadataAdapterError
constructor
Initializes this metadata adapter error with the specified error message and error code.
Methods inherited from Error
Constructor Details
#initialize(message, code) ⇒ MetadataAdapterError
Initializes this metadata adapter error with the specified error message and error code.
109 110 111 112 113 114 |
# File 'lib/lightstreamer/errors.rb', line 109 def initialize(, code) = @adapter_error_code = code.to_i super end |
Instance Attribute Details
#adapter_error_code ⇒ Fixnum (readonly)
Returns The error code from the metadata adapter.
106 107 108 |
# File 'lib/lightstreamer/errors.rb', line 106 def adapter_error_code @adapter_error_code end |
#adapter_error_message ⇒ String (readonly)
Returns The error message from the metadata adapter.
103 104 105 |
# File 'lib/lightstreamer/errors.rb', line 103 def end |