Exception: Lightstreamer::SessionEndError
- Defined in:
- lib/lightstreamer/errors.rb
Overview
This error is raised when the specified session ID is for a session that has been terminated.
Instance Attribute Summary collapse
-
#cause_code ⇒ Fixnum
readonly
The cause code specifying why the session was terminated by the server, or
nilif unknown.
Instance Method Summary collapse
-
#initialize(cause_code = nil) ⇒ SessionEndError
constructor
Initializes this session end error with the specified cause code.
Methods inherited from Error
Constructor Details
#initialize(cause_code = nil) ⇒ SessionEndError
Initializes this session end error with the specified cause code.
130 131 132 133 |
# File 'lib/lightstreamer/errors.rb', line 130 def initialize(cause_code = nil) @cause_code = cause_code.to_i super() end |
Instance Attribute Details
#cause_code ⇒ Fixnum (readonly)
125 126 127 |
# File 'lib/lightstreamer/errors.rb', line 125 def cause_code @cause_code end |