Exception: Lightstreamer::UnfilteredDispatchingNotSupportedForItemError
- Inherits:
-
Error
- Object
- StandardError
- Error
- Lightstreamer::UnfilteredDispatchingNotSupportedForItemError
- Defined in:
- lib/lightstreamer/errors.rb
Overview
This error is raised when unfiltered dispatching is requested on an item that does not support it.