Exception: Lightstreamer::UnsupportedModeForItemError
- Defined in:
- lib/lightstreamer/errors.rb
Overview
This error is raised when the specified subscription mode is not supported by one of the items.
This error is raised when the specified subscription mode is not supported by one of the items.